SitefSettingsClisitef class

Constructors

SitefSettingsClisitef({String serverIp = '', String storeCode = '', String posNumber = '', String additionalParameters = '', String operatorPos = '', String companyDocument = '', String lib = '', String comExternal = '', String isDoubleValidation = '', String otp = '', String enabledTransactions = '', String automationDocument = ''})
const
SitefSettingsClisitef.fromJson(String source)
factory
SitefSettingsClisitef.fromMap(Map<String, dynamic> map)
factory

Properties

additionalParameters String
final
automationDocument String
final
comExternal String
final
companyDocument String
final
enabledTransactions String
final
hashCode int
The hash code for this object.
no setterinherited
isDoubleValidation String
final
lib String
final
operatorPos String
final
otp String
final
posNumber String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
serverIp String
final
storeCode String
final

Methods

copyWith({String? serverIp, String? storeCode, String? posNumber, String? additionalParameters, String? operatorPos, String? companyDocument, String? lib, String? comExternal, String? isDoubleValidation, String? otp, String? enabledTransactions, String? automationDocument}) SitefSettingsClisitef
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() String
toMap() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited