PaymentTypeHandler enum

Inheritance
Available extensions

Values

ON_TRANSACTION_SUCCESS → const PaymentTypeHandler
ON_ERROR → const PaymentTypeHandler
ON_MESSAGE → const PaymentTypeHandler
ON_LOADING → const PaymentTypeHandler
WRITE_TO_FILE → const PaymentTypeHandler
ON_ABORTED_SUCCESSFULLY → const PaymentTypeHandler
DISPOSE_DIALOG → const PaymentTypeHandler
ACTIVE_DIALOG → const PaymentTypeHandler
ON_AUTH_PROGRESS → const PaymentTypeHandler
ON_TRANSACTION_INFO → const PaymentTypeHandler
ON_FINISHED_RESPONSE → const PaymentTypeHandler
ON_CHANGED → const PaymentTypeHandler

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
method → dynamic

Available on PaymentTypeHandler, provided by the PaymentTypeHandlerExt extension

no setter
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<PaymentTypeHandler>
A constant List of the values in this enum, in order of their declaration.