PaymentTypeTransaction enum

Inheritance
Available extensions

Values

CREDIT → const PaymentTypeTransaction
DEBIT → const PaymentTypeTransaction
VOUCHER → const PaymentTypeTransaction
PIX → const PaymentTypeTransaction

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type → dynamic

Available on PaymentTypeTransaction, provided by the PaymentTypeTransactioneExt extension

no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<PaymentTypeTransaction>
A constant List of the values in this enum, in order of their declaration.