PaymentTypeCall enum
- Inheritance
- Available extensions
Values
- CREDIT → const PaymentTypeCall
- CREDIT_PARC → const PaymentTypeCall
- DEBIT → const PaymentTypeCall
- PIX → const PaymentTypeCall
- VOUCHER → const PaymentTypeCall
- ABORT → const PaymentTypeCall
- ABORT_PIX → const PaymentTypeCall
- LAST_TRANSACTION → const PaymentTypeCall
- REFUND → const PaymentTypeCall
- ACTIVEPINPAD → const PaymentTypeCall
- ACTIVEPINPAD_CREDENTIALS → const PaymentTypeCall
- PINPAD_AUTHENTICATED → const PaymentTypeCall
- CANCEL_TRANSACTION → const PaymentTypeCall
- REVERSAL → const PaymentTypeCall
- PRINTER_TRANSACTION → const PaymentTypeCall
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- method → dynamic
-
Available on PaymentTypeCall, provided by the PaymentTypeCallExt extension
no setter - name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
PaymentTypeCall> - A constant List of the values in this enum, in order of their declaration.